<?php
/**
 * VuFind Bootstrapper
 *
 * PHP version 7
 *
 * Copyright (C) Leipzig University Library 2020.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  Bootstrap
 * @author   Robert Lange <lange@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org Main Site
 */
namespace finc;

use Laminas\Console\Console;

/**
 * Finc Bootstrapper
 *
 * @category VuFind
 * @package  Bootstrap
 * @author   Robert Lange <lange@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org Main Site
 */
class Bootstrapper extends \VuFind\Bootstrapper
{
    /**
     * Bootstrap finc resources.
     *
     * @return void
     */
    public function bootstrap()
    {
        // automatically call all methods starting with "init":
        $methods = get_class_methods($this);
        foreach ($methods as $method) {
            if (substr($method, 0, 8) == 'initFinc') {
                $this->$method();
            }
        }
    }

    /**
     * Set up custom error page based on exception information.
     *
     * @return void
     */
    protected function initFincCustomErrorView()
    {
        //custom error page not needed in console mode:
        if (\Laminas\Console\Console::isConsole()) {
            return;
        }

        $callback = function ($e) {
            $exception = $e->getParam('exception');
            if (!$exception) {
                return;
            }

            if ($exception instanceof \VuFindSearch\Backend\Exception\BackendException && $exception->getPrevious()) {
                $exception = $exception->getPrevious();
            }

            $exceptionArray = explode('\\', get_class($exception));
            $exceptionName = end(
                $exceptionArray
            );

            $resolver = $e->getApplication()
                ->getServiceManager()->get('Laminas\View\Resolver\TemplatePathStack');

            if (false === $resolver->resolve($template = "error/$exceptionName")) {
                // custom error template does not exist
                return;
            }

            $model = new \Laminas\View\Model\ViewModel(
                [
                'display_exceptions' => APPLICATION_ENV == 'development',
                'exception' => $e->getParam('exception'),
                ]
            );
            $model->setTemplate($template);
            $e->setResult($model);
        };

        $this->events->attach('dispatch.error', $callback);
    }
}
