<?php
/**
 * Copyright (C) Leipzig University Library 2020.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @author   Dorian Merz <merz@ub.uni-leipzig.de>
 * @author   Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
namespace finc\Controller\Admin;

use Psr\Container\ContainerInterface;
use VuFind\Config\PluginManager;
use Laminas\Mvc\I18n\Translator;
use Laminas\ServiceManager\ServiceLocatorInterface;

class I18nControllerFactory
{
    /**
     * @param ContainerInterface|ServiceLocatorInterface $container
     *
     * @return I18nController
     */
    public function __invoke(ContainerInterface $container)
    {
        /** @var PluginManager $configManager */
        $configManager = $container->get(PluginManager::class);
        $languages = $configManager->get('config')->Languages->toArray();
        $translator = $container->get(Translator::class)->getTranslator();
        return new I18nController($container, $translator, $languages);
    }
}