<?php
/**
 * Book Cover Generator
 *
 * PHP version 7
 *
 * Copyright (C) Villanova University 2007.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  Cover_Generator
 * @author   Andrew S. Nagy <vufind-tech@lists.sourceforge.net>
 * @author   Demian Katz <demian.katz@villanova.edu>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/configuration:external_content Wiki
 */
namespace finc\Cover;

/**
 * Book Cover Generator
 *
 * @category VuFind
 * @package  Cover_Generator
 * @author   Andrew S. Nagy <vufind-tech@lists.sourceforge.net>
 * @author   Demian Katz <demian.katz@villanova.edu>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/configuration:external_content Wiki
 */
class Loader extends \VuFind\Cover\Loader
{
    const EMPTY_IMAGE_CONTENT = 'nothing here';

    /**
     * Flag denoting the last loaded image was a FailImage
     *
     * @var bool
     */
    protected $hasLoadedUnavailable = false;

    /**
     * {@inheritdoc}
     * Adds @see self::$hasLoadedUnavailable flag
     *
     * @return void
     */
    public function loadUnavailable()
    {
        $this->hasLoadedUnavailable = true;
        if ($this->config->Content->useCoverFallbacksOnFail && !empty($this->localFile)) {
            file_put_contents($this->localFile, self::EMPTY_IMAGE_CONTENT);
        }
        return parent::loadUnavailable();
    }

    public function loadImage($settings = [])
    {
        parent::loadImage($settings);
        if ($this->image === self::EMPTY_IMAGE_CONTENT) {
            $this->hasLoadedUnavailable = true;
        }
    }

    public function getImage()
    {
        if ($this->image === self::EMPTY_IMAGE_CONTENT) {
            $this->hasLoadedUnavailable = true;
        }
        return parent::getImage();
    }
}
