<?php
/**
 * Munger Injection Factory
 *
 * A Delegator Factory that registers several listeners at events triggered by the
 * VuFind\Search service.
 *
 * PHP version 7
 *
 * Copyright (C) Leipzig University Library 2019.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  Finc/Service
 * @author   Dorian Merz <merz@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org Main Page
 */
namespace finc\ILS\Driver;

use Interop\Container\ContainerInterface;
use VuFindSearch\Query\Query;
use VuFindSearch\Query\QueryGroup;
use VuFindSearch\Service as SearchService;
use Laminas\Config\Config;
use Laminas\EventManager\EventInterface;
use Laminas\ServiceManager\Factory\DelegatorFactoryInterface;

/**
 * Munger Injection Factory
 *
 *
 * @category VuFind
 * @package  Finc/ILS
 * @author   Dorian Merz <merz@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org Main Page
 */
class StaticStatusRulesDelegatorFactory implements DelegatorFactoryInterface
{
    /**
     * Adds staticStatusRules if there is a valid StaticStatusRules.json available
     *
     * @param ContainerInterface $container
     * @param string $name
     * @param callable $callback
     * @param array|null $options
     *
     * @return mixed
     */
    public function __invoke(
        ContainerInterface $container,
        $name,
        callable $callback,
        array $options = null
    ) {
        $instance = call_user_func($callback);

        $staticStatusRules = $container->get('VuFind\YamlReader')->get('StaticStatusRules.yaml');
        if (!empty($staticStatusRules)) {
            if (isset($staticStatusRules['rules']) && isset($staticStatusRules['stopFlags'])) {
                $instance->staticStatusRules = $staticStatusRules;
            }
        }

        return $instance;
    }
}
