<?php
/**
 * Copyright (C) Leipzig University Library 2020.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @author   Dorian Merz <merz@ub.uni-leipzig.de>
 * @author   Sebastian Kehr <kehr@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */

namespace finc\Listener;

use Symfony\Component\Filesystem\Filesystem;
use Laminas\EventManager\AbstractListenerAggregate;
use Laminas\EventManager\EventManagerInterface;
use Laminas\Mvc\I18n\Translator;
use Laminas\Mvc\MvcEvent;

class I18nDataDirListener extends AbstractListenerAggregate
{
    protected const EVENT = MvcEvent::EVENT_DISPATCH;

    protected const DIR = APPLICATION_PATH . '/data/i18n/languages';

    public function attach(EventManagerInterface $events, $priority = 8000)
    {
        $events->attach(static::EVENT, [$this, 'onDispatch'], $priority);
    }

    public function onDispatch(MvcEvent $event)
    {
        if (!is_dir($dir = self::DIR)) {
            (new Filesystem())->mkdir($dir);
        }

        $event->getApplication()->getServiceManager()->get(Translator::class)
            ->getPluginManager()->get('ExtendedIni')->addToPathStack($dir);
    }
}