<?php
/**
 * RecordViewHelper Factory Class
 *
 * PHP version 7
 *
 * Copyright (C) Leipzig University Library 2022.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  View_Helpers
 * @author   Robert Lange <lange@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development:plugins:hierarchy_components Wiki
 */
namespace finc\View\Helper\Root;

use finc\Rewrite\EblRewrite;
use Interop\Container\ContainerInterface;
use Laminas\ServiceManager\Factory\FactoryInterface;

/**
 * ViewHelper Factory Class
 *
 * @category VuFind
 * @package  View_Helpers
 * @author   Robert Lange <lange@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development:plugins:hierarchy_components Wiki
 */
class RecordViewHelperFactory implements FactoryInterface
{
    /**
     * Create an object
     *
     * @param ContainerInterface $container     Service manager
     * @param string             $requestedName Service being created
     * @param null|array         $options       Extra options (optional)
     *
     * @return Record
     *
     * @throws ServiceNotFoundException if unable to resolve the service.
     * @throws ServiceNotCreatedException if an exception is raised when
     * creating a service.
     * @throws ContainerException if any other error occurs
     */
    public function __invoke(
        ContainerInterface $container,
        $requestedName,
        array $options = null
    ) {
        if (!empty($options)) {
            throw new \Exception('Unexpected options sent to factory.');
        }
        $recordViewHelper = new $requestedName(
            $container->get('VuFind\Config')->get('config'),
            $container->get('ViewHelperManager')->get('url'),
            $container->get('VuFind\AuthManager'),
            $container->get(EblRewrite::class),
            $container->get('VuFind\Config')->get('Resolver'),
            $container->get('VuFind\Config')->get('iconMapping')
        );

        //due to https://github.com/vufind-org/vufind/pull/718
        //we have to explicitly add the cover router (cf. #
        $recordViewHelper->setCoverRouter($container->get('VuFind\Cover\Router'));

        return $recordViewHelper;
    }
}
