<?php
namespace Selenium\adlr;

use Facebook\WebDriver\WebDriverBy;
use Facebook\WebDriver\WebDriverExpectedCondition;

trait GetitTestBaseTrait
{
    /*
     * open record url and test each rule set
     */
    public function runGetItRecord($record): void
    {
        $this->log("object id of webdriver: " . spl_object_id($this->wd));
        $this->wd->get(self::$host . self::$port . '/Record/' . $record);
        $this->wd->takeScreenshot("logs/adlr/info{$record}" . ($this->user ? '-' . $this->user : '') . ".png");

        foreach (self::RULES ?? [] as $rule) {
            if ($rule["waitForClass"]) {
                $this->waitForClass($rule["waitForClass"], true);
            }
            if ($rule["waitForId"]) {
                $this->waitForId($rule["waitForId"], true);
            }
            if ($rule["waitForLinkText"]) {
                $this->waitForLinkText($rule["waitForLinkText"], true);
            }
            if ($rule["wait"]) {
                try {
                    $this->wd->wait(5, 5000)->until(
                        WebDriverExpectedCondition::elementTextContains(
                            WebDriverBy::className($rule["wait"]),
                            $rule["text"]
                        )
                    );
                } catch (\Facebook\WebDriver\Exception\NoSuchElementException $x) {
                    $this->log("Timeout for $record when fething {$rule["wait"]}.");
                }
            }
            try {
                $value = $this->findByCss($rule["path"])->getText();
            } catch (\Facebook\WebDriver\Exception\NoSuchElementException $x) {
                $value = false;
            }
            switch ($rule["type"] ?? '') {
                case 'text':
                    $this->assertEqualsIgnoringCase(
                        $rule["text"],
                        $value,
                        $rule["path"] . ($value === false ? " does not exists" : " is '" . $value . "' ")
                        . ", but should be '" . $rule["text"] . "'"
                    );
                    break;
                case 'contains':
                    $this->assertStringContainsStringIgnoringCase(
                        $rule["text"],
                        $value,
                        $record . ": " .
                        $rule["path"] . ($value === false ? " does not exists" : " is '" . $value . "' ")
                        . ", but should contain '" . $rule["text"] . "'"
                    );
                    break;
                case 'anti-exi':
                    $this->assertNotEqualsIgnoringCase(
                        $rule["text"],
                        $value,
                        $rule["path"] . " must not be equals to '" . $rule["text"] . "'"
                    );
                    break;
            }
        }
    }

    /*
     * prepare records to fit in data provider array foramt
     * test function iteself needs to be annotated by: @dataProvider provideRecords
     *
     * php unit test data provider:
     * https://blog.martinhujer.cz/how-to-use-data-providers-in-phpunit/
     */
    public function provideRecords()
    {
        $data = [];
        foreach (self::RECORDS as $record) {
            $data[$record] = [$record];
        }
        return $data;
        /* $data will looks like:
         * [
         *      'finc-87-14159' => ["finc-87-14159"],
         *      '0-1027717349' => ["0-1027717349"]
         * ]
         */
    }

    /**
     * @dataProvider provideRecords
     */
    public function testRecord($record) : void
    {
        $this->runGetItRecord($record);
    }

    protected function setUp(): void
    {
        AdlrBase::setUp();
        if (method_exists($this, 'login')) {
            $this->login("{$this->getUserName()}@adlr.link", $this->getPassword());
        }
    }
}
