<?php
namespace Selenium\adlr;

use Facebook\WebDriver\WebDriverBy;
use Facebook\WebDriver\WebDriverCheckboxes;
use Facebook\WebDriver\WebDriverExpectedCondition;
use Facebook\WebDriver\WebDriverSelect;

/**
 * @group adlr
 * @group adlr-order
 */
class OrderTest extends AdlrLoginBase
{
    use LibrarianTrait;

    public function testCreateOrderByUser()
    {
        $this->logout();
        $this->assertTrue($this->login("{$this->getUserName()}@adlr.link", $this->getPassword()));
        $this->runCreateOrderByUser();
        $this->logout();
    }

    public function testDeleteOrder()
    {
        $this->runDeleteOrder();
    }

    protected function runCreateOrderByUser()
    {
        $this->log("Login as {$this->getUserName()} and create order.");
        $this->findById('account-icon')->click();
        $this->log("Show account of user.");

        $this->log("Create order for partial copy.");
        $this->wd->get(self::$host . self::$port . '/Record/127-HF000189856');
        $this->findByXpath("//a[contains(@href,'/fidSubitoPartialCopy')]")->click();
        $this->waitForName('pages');
        // TODO: try some invalid inputs
        $this->findByName('pages')->sendKeys('3-4');
        $this->findByName('comment')->sendKeys('Harry Potter sucks.');
        $this->wd->takeScreenshot("logs/adlr/orders/{$this->getUserName()}_create_order_form.png");
        $this->findByName('fid-acquisition-form')->submit();
        $this->wd->wait(10, 1000)->until(
            WebDriverExpectedCondition::elementTextContains(
                WebDriverBy::className('alert-success'),
                'Ihre Bestellung wurde entgegengenommen und wird nun von uns bearbeitet.'
            )
        );
        $this->wd->takeScreenshot("logs/adlr/orders/{$this->getUserName()}_create_order_success.png");
        $this->wd->get(self::$host . self::$port . '/MyResearch/Home');

        $this->log("Go to user orders.");
        $this->findByXpath("//a[contains(@href,'/fid/user/order')]")->click();
        $this->wd->takeScreenshot("logs/adlr/orders/{$this->getUserName()}_create_order_pages.png");
        $this->assertNotEmpty($this->findByXpath("//a[contains(@href,'/Record/127-HF000189856')]")->getText());
        $this->logout();
    }

    protected function runDeleteOrder()
    {
        $this->logout();
        $this->log("Delete last order of user {$this->getUserName()} by admin.");
        $this->wd->manage()->window()->fullscreen();
        $this->login("admin@adlr.link", 'test123$');
        $this->findById('account-icon')->click();
        $this->findByXpath("//a[contains(@href,'/fid/admin/orders')]")->click();
        $lastOrderTitle = $this->findByXpath(
            "//*[@id='content']/table/tbody/tr[2]/td[4]/a"
        )->getText();
        $this->assertContains("Harry Potter", $lastOrderTitle);
        $this->wd->takeScreenshot("logs/adlr/orders/{$this->getUserName()}_create_order_delete.png");
        $this->findByXpath("//*[@id='content']/table/tbody/tr[2]/td[5]/a")->click(); // TODO use unique selector
        $this->findByXpath("//*[@id='orderDeleteModal']/div/div/div[3]/a")->click(); // TODO use unique selector
        $this->wd->wait(10, 1000)->until(
            WebDriverExpectedCondition::elementTextContains(
                WebDriverBy::className('alert-success'),
                'Bestellung gelöscht'
            )
        );
        $this->wd->takeScreenshot("logs/adlr/orders/{$this->getUserName()}_create_order_delete_success.png");
        $this->logout();
    }
}
