<?php
namespace Selenium\adlr;

use Facebook\WebDriver\WebDriverBy;
use Facebook\WebDriver\WebDriverCheckboxes;
use Facebook\WebDriver\WebDriverExpectedCondition;
use Facebook\WebDriver\WebDriverSelect;

/**
 * @group adlr
 * @group adlr-delete
 * @group adlr-delete-librarian
 */
class UserDeleteTest extends AdlrLoginBase
{
    use LibrarianTrait;

    public function testDeleteByUser()
    {
        $this->logout();
        $this->assertTrue($this->login("{$this->getUserName()}@adlr.link", $this->getPassword()));
        $this->runDeleteByUserTest();
        $this->logout();
    }

    public function testReactivateUser()
    {
        $this->runReactivateUser();
    }

    protected function runDeleteByUserTest()
    {
        $this->log("Login as {$this->getUserName()} and mark own account for delete.");
        $this->wd->get(self::$host . self::$port);
        $this->findById('account-icon')->click();
        $this->log("Show account of user.");

        $this->log("Go to user delete form.");
        $this->findByXpath("//a[contains(@href,'/fid/user/delete')]")->click();
        $this->waitForName('passwordConfirmation');
        $this->findByName('passwordConfirmation')->sendKeys($this->getPassword());
        $this->wd->takeScreenshot("logs/adlr/user/delete/{$this->getUserName()}_1_deletes_account.png");
        $this->findByName('submit')->click();
        $this->wd->wait(10, 1000)->until(
            WebDriverExpectedCondition::elementTextContains(
                WebDriverBy::cssSelector('.modal-body > h1'),
                'Konto gesperrt und zur Löschung vorgemerkt.'
            )
        );
        $this->wd->takeScreenshot("logs/adlr/user/delete/{$this->getUserName()}_2_account_delete_success.png");
        $this->logout();

        $this->log("Try to log in again - should fail...");
        $this->wd->get(self::$host . self::$port . '/MyResearch/UserLogin');
        $this->findById('login_Authenticator_username')->sendKeys($this->getUserName() . "@adlr.link");
        $this->findById('login_Authenticator_password')->sendKeys($this->getPassword());
        $this->findByName('loginForm')->submit();
        $this->wd->wait(10, 1000)->until(
            WebDriverExpectedCondition::elementTextContains(
                WebDriverBy::className('alert-danger'),
                'Ihr Konto ist zur Löschung vorgemerkt und Ihre Daten werden beim nächsten Wartungslauf endgültig entfernt.'
            )
        );
        $this->wd->takeScreenshot("logs/adlr/user/delete/{$this->getUserName()}_3_account_blocked.png");
    }

    protected function runReactivateUser()
    {
        $this->log("Reactivate account of user {$this->getUserName()} by admin.");
        $this->wd->manage()->window()->fullscreen();
        $this->login("admin@adlr.link", 'test123$');
        $this->findById('account-icon')->click();
        $this->wd->get(self::$host . self::$port . '/fid/admin/list');
        $userId = $this->findByXpath(
            "//tr/td[text()='{$this->getUserName()}@adlr.link']//preceding-sibling::th"
        )->getText();
        $this->log("Found userID $userId");
        $this->wd->get(self::$host . self::$port . '/fid/admin/edit/' . $userId);
        $selectElement = $this->wd->findElement(WebDriverBy::name('permissions[basic_access]'));
        $select = new WebDriverSelect($selectElement);
        $select->selectByValue('granted');
        $deleteElement = $this->findById('deleted');
        $delete = new WebDriverCheckboxes($deleteElement);
        $delete->deselectAll();
        $this->wd->takeScreenshot("logs/adlr/user/delete/{$this->getUserName()}_4_reactivate_account.png");
        $this->wd->executeScript('window.scrollBy(0,document.body.scrollHeight);');
        $this->findByName('submit')->click();
        $this->wd->wait(10, 1000)->until(
            WebDriverExpectedCondition::elementTextContains(
                WebDriverBy::className('alert-info'),
                'Ihr Profil wurde erfolgreich aktualisiert.'
            )
        );
        $this->wd->takeScreenshot("logs/adlr/user/delete/{$this->getUserName()}_5_account_active_info.png");
        $this->logout();
    }
}
