<?php
/**
 * PHP version 7
 *
 * Copyright (C) Villanova University 2022.
 * Copyright (C) Leipzig University Library 2022.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  finc
 * @author   Robert Lange  <lange@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 */
namespace fincTest\RecordDriver;

use finc\RecordDriver\SolrAI as SolrAIDriver;
use VuFindTest\Unit\TestCase as VuFindTestCase;

/**
 * SolrAITestCase
 *
 * @category VuFind
 * @package  finc
 * @author   Robert Lange  <lange@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     http://vufind.org
 */
class SolrAITestCase extends SolrBaseTestCase
{
    protected function getDriverMock()
    {
        return new SolrAIDriverMock();
    }

    /** @test */
    public function getPagesTest(): void
    {
        $this->driver = $this->getDriverMock();
        $this->getAiData('ai-49-aHR0cDovL2R4LmRvaS5vcmcvMTAuMTU5Ni85NzgtMS00NjQ4LTE2NjUtOV9jaDQ');
        $expected = '129-160';
        $this->assertSame($expected, $this->driver->getPages(), "Pages should be '{$expected}'.");
    }

    public function testCitaviExport()
    {
        /* TODO
        // to get fields / ai data, print data in driver with
        // file_put_contents(__DIR__ . "/../../../tests/fixtures/export/{$this->fields['id']}_fields.txt", var_export($this->fields, true));
        */
        foreach (['ai-49-aHR0cDovL2R4LmRvaS5vcmcvMTAuMTU5Ni85NzgtMS00NjQ4LTE2NjUtOV9jaDQ'] as $recordId) {
            $this->getAiData($recordId);
            eval('$fields = ' . $this->getFixtureData("export/{$recordId}_fields.txt", false) . ';');
            $this->driver->setFields($fields);
            $renderer = $this->getPhpRenderer($this->getPlugins($recordId));
            $this->assertEquals(
                $this->getFixtureData("export/citavi/{$recordId}.enw", false),
                $renderer->render(
                    'RecordDriver/AbstractBase/export-citavi.phtml',
                    [
                        'driver' => $this->driver,
                        'this'  => $this
                    ]
                )
            );
        }
    }

    /**
     * @return void
     */
    protected function getAiData($record): void
    {
        $ai = [];
        $ai['authors'] = [0 => []];
        $ai['rft.pages'] = '129-160';
        $ai['finc.id'] = "$record";
        $ai['finc.format'] = 'ElectronicBookPart';
        $ai['rft.epage'] = '160';
        $ai['rft.tpages'] = '32';
        $ai['rft.spage'] = '129';
        $ai['finc.source_id'] = '49';
        $ai['ris.type'] = 'ECHAP';
        $ai['rft.atitle'] = 'Global Economic Prospects, June 2021: Emerging Inflation Pressures: Cause for Alarm?';
        $ai['rft.genre'] = 'bookitem';
        $ai['rft.jtitle'] = 'Global Economic Prospects, June 2021';
        $ai['rft.date'] = '2021-07-27';
        $ai['x.date'] = '2021-07-27T00:00:00Z';
        $ai['doi'] = '10.1596/978-1-4648-1665-9_ch4';
        $ai['version'] = '0.9';
        $ai['x.type'] = 'book-chapter';
        $ai['x.oa'] = '1';
        $this->driver->setAIRecord($ai);
        $this->driver->setId(123);
    }
}

class SolrAIDriverMock extends SolrAIDriver
{
    public function setId($id)
    {
        $this->id = $id;
    }

    public function setAIRecord(array $airecord)
    {
        $this->aiRecord = $airecord;
    }

    public function setIsils(array $isils)
    {
        $this->isil = $isils;
    }

    public function getUniqueId()
    {
        return $this->id;
    }

    public function setFields(array $fields)
    {
        $this->fields = $fields;
    }
}
