<?php
/**
 * PHP version 5
 *
 * Copyright (C) Villanova University 2010.
 * Copyright (C) project swissbib, University Library Basel, Switzerland
 * Copyright (C) Leipzig University Library 2015.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  finc
 * @author   Guenter Hipler <guenter.hipler@unibas.ch>
 * @author   Frank Morgner  <morgnerf@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     http://www.swissbib.org
 */
namespace fincTest\RecordDriver;

use finc\RecordDriver\SolrMarcFinc as SolrMarcFincDriver;
use finc\RecordDriver\SolrMarcFincTrait;
use VuFindTest\Unit\TestCase as VuFindTestCase;

/**
 * SolrMarcTestCase
 *
 * @category VuFind
 * @package  finc
 * @author   Guenter Hipler  <guenter.hipler@unibas.ch>
 * @author   Frank Morgner  <morgnerf@ub.uni-leipzig.de>
 * @author   Robert Lange  <lange@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     http://vufind.org
 */
class SolrMarcFincTestCase extends SolrBaseTestCase
{
    /**
     * @return void
     */
    public function testGetURLs()
    {
        // although not current isil, link for IIIF should be shown based on indicator 2 #20600
        $this->runGetURLsTestCase('IIIF_0-1763648745');
        $this->runGetURLsTestCase('IIIF_0-1763648745', ['DE-15']);

        // Record 0-1497294835 with isil of DE-15 in fullrecord (subfield 9) results in empty array for adlr #18915
        $this->runGetURLsTestCase('isil_with_DE-15_0-1497294835', ['DE-15-FID'], []);
        $this->runGetURLsTestCase('isil_with_DE-15_0-1497294835', ['FID-MEDIEN-DE-15'], []);
        // .. but is shown in DE-15
        $this->runGetURLsTestCase('isil_with_DE-15_0-1497294835', ['DE-15']);

        // Record 0-1497294835 has no given isil in fullrecord (subfield 9) => shown as default / fallback #18915
        $this->runGetURLsTestCase('no_isil_for_22-15-qucosa-161943', ['DE-15-FID']);
        $this->runGetURLsTestCase('no_isil_for_22-15-qucosa-161943', ['DE-15']);
    }

    protected function getDriverMock()
    {
        return new SolrMarcFincDriverMock();
    }

    /**
     * @return void
     */
    public function runGetURLsTestCase(string $testCase, array $isils = [], $expectedResult = null)
    {
        $driver = $this->getDriverMock();
        $driver->setFullRecord($this->getFixtureData("getUrls/{$testCase}_fullrecord.txt", false));
        $driver->setIsils($isils);
        $actualResult = $driver->getURLs();
        $expectedResult = $expectedResult ?? $this->getFixtureData("/getUrls/{$testCase}_result.json");
        $this->assertEquals($expectedResult, $actualResult);
    }

    /**
     * @return void
     */
    public function testGetTitleDetails(): void
    {
        $fixtures = [
            '106-IDC14405'               => 'DE-15',
            'finc-147-978-0-230-27613-0' => 'DE-15'
        ];

        $this->runTestGetTitleDetails($fixtures, true);
    }

    /**
     * @return void
     */
    public function testGetTitleDetailsSetPunctuation(): void
    {
        // "245a: 245b (245n); 245p/ 245c"
        $fixtures = [
            '0-682748102'  => 'DE-15', // |a Faust  |b eine Tragödie  |c Goethe
            '0-1144749735' => 'DE-15', // |a Briefe der Frau Rat Goethe  |c ausgew. und hrsg. von Rudolf Bach
            '0-1172722633' => 'DE-15', // |a Faust  |n 2  |p Der Tragödie zweiter Teil / mit Ill. von Max Slevogt  |c Johann Wolfgang Goethe
            '0-1070158569' => 'DE-15', // |a C. Plini Secundi Naturalis Historiae libri XXXVII  |n 5  |p Libri XXXI - XXXVII
            '0-130143812'  => 'DE-15', // |a Academische Revue  |b Zeitschrift für das internationale Hochschulwesen  |c in Verbindung mit den Hochschulnachrichten hrsg. von der Centralstelle für das Internationale Hochschulwesen in München
            '0-229443699'  => 'DE-15', // |a Kunsthistorische Sammlungen des allerhöchsten Kaiserhauses  |b Gemälde; beschreibendes Verzeichnis  |n Bd. 1  |p Italienische, Spanische und Französische Schulen  |c von Eduard R. von Engerth
            '0-647227738'  => 'DE-15', // |a Die Verwaltung bei den Justizbehörden in Preußen  |b Handbuch zum praktischen Gebrauch in zwei Abtheilungen  |n Abtheilung 2  |p Bestimmungen über die Verwaltung im allgemeinen insbesondere über die persönichen Verhältnisse der Beamten nach den Gesetzen, Verordnungen, Erlassen, Ministerial-Verfügungen etc. mit Berücksichtigung der Verwaltungsgrundsätze, systematisch bearbeitet und erläutert  |n Bd. 2  |c von Hertting
            '0-130271578'  => 'DE-15', // |a Veröffentlichungen des Seminars für Orientalische Kunstgeschichte an der Universität Bonn  |n Reihe B  |p Antiquitates orientales
            '0-1072033011' => 'DE-15'  // |a Slawische Altertumskunde des östlichen Mitteleuropas im 9. und 10. Jahrhundert  |n 3  |c Helmut Preidel
        ];

        $this->runTestGetTitleDetails($fixtures, false);
    }

    /**
     * @param array $fixtures
     * @param bool  $hasPunctuation
     *
     * @return void
     */
    protected function runTestGetTitleDetails(array $fixtures, $hasPunctuation): void
    {
        foreach ($fixtures as $recordId => $isil) {
            $driver = $this->getDriverMock();
            $driver->setFullRecord($this->getFixtureData("getTitleDetails/{$isil}/{$recordId}_fullrecord.txt", false));
            $this->assertEquals(
                $driver->hasPunctuation(),
                $hasPunctuation,
                "{$isil}: Record {$recordId} " . ($hasPunctuation ? "has no punctuation as expected." : "has punctuation but shouldn't.")
            );
            $expected = $this->getFixtureData("getTitleDetails/{$isil}/{$recordId}_result.txt", false);
            $this->assertEquals(
                $expected,
                implode($driver->getTitleDetails()),
                "{$isil}: Record {$recordId} title punctuation does not match expected result: \"" . $expected . "\""
            );
        }
    }

    /** @test */
    public function getPagesTest(): void
    {
        foreach (['0-1139343203', '0-1797111302'] as $record) {
            eval('$fixture = ' . $this->getFixtureData("export/{$record}_fields.txt", false) . ';');
            $this->driver->setFields($fixture);
            $expected = '[1] Bl.';
            $this->assertSame($expected, $this->driver->getPages(), "Pages should be '{$expected}'.");
        }
    }

    public function testCitaviExport()
    {
        // to get fields / ai data, print data in driver with
        //         file_put_contents(__DIR__ . "/../../../tests/fixtures/export/{$this->fields['id']}_fields.txt", var_export($this->fields, true));
        foreach (['0-1797111302'] as $record) {
            eval('$fields = ' . $this->getFixtureData("export/{$record}_fields.txt", false) . ';');
            $this->driver->setFields($fields);
            $renderer = $this->getPhpRenderer($this->getPlugins($record));
            $this->assertEquals(
                $this->getFixtureData("export/citavi/{$record}.enw", false),
                $renderer->render(
                    'RecordDriver/AbstractBase/export-citavi.phtml',
                    [
                        'driver' => $this->driver,
                        'this'  => $this
                    ]
                )
            );
        }
    }
}

class SolrMarcFincDriverMock extends SolrMarcFincDriver
{
    use SolrMarcFincTrait;

    public function setFullRecord(string $fullrecord)
    {
        $this->fields['fullrecord'] = $fullrecord;
    }

    public function setFields(array $fields)
    {
        $this->fields = $fields;
    }

    public function setField(string $field, string $value)
    {
        $this->fields[$field] = $value;
    }

    public function setIsils(array $isils)
    {
        $this->isil = $isils;
    }
}
